local Mockingbird = ...


---------------
--set up
---------------
Mockingbird:registerEnumValue( "RESOURCE_TYPE", "RESOURCE_MAGIC" )
Mockingbird:registerAssetId("icons/Magic.png", "ICON_MAGIC")

Mockingbird:registerAssetId("models/mockingbird.fbx/Materials/pentagram3", "PENTAGRAM_MATERIAL3")
Mockingbird:override({
    Id = "PENTAGRAM_MATERIAL3",
	HasAlphaTest = true
})


---------------
-- NEW Specific Resource Generators
---------------
Mockingbird:register({ 
    DataType = "BUILDING_FUNCTION_RESOURCE_GENERATOR",
    Id = "MAGIC_GENERATOR_FUNCTION",
    ResourceGenerated = "RESOURCE_MAGIC",
    IsForConsumer = true,
    IsInfinite = false
})

---------------
-- New Resource Magic 
---------------

Mockingbird:register({
    DataType = "RESOURCE",
    Id = "RESOURCE_MAGIC",
    ResourceName = "RESOURCE_MAGIC_NAME",
    OrderId = 15,
    Icon = "ICON_MAGIC",
    ResourceTypeList = { "SERVICE", "RESOURCE_MAGIC" },
    IsTradable = false,
    ResourceLayoutType = "CRATES",
    VillagerBuyingPrice = { Resource = "GOLD", Quantity = 1 },
    DisplayInInventory = true
})
---------------
-- Asset IDs --
---------------
Mockingbird:registerAssetId("models/mockingbird.fbx/Prefab/Afortune_Part", "PREFAB_AFORTUNE_PART")

Mockingbird:registerAssetId("models/mockingbird.fbx/Prefab/Alamp_Part", "PREFAB_ALAMP_PART")
Mockingbird:registerAssetId("models/markets.fbx/Prefab/Adirt_Part", "PREFAB_ADIRT_PART")
--Outfits
Mockingbird:registerAssetId("models/outfits.fbx/Prefab/AFemaleFront", "PREFAB_FORTUNE_FEMALE_FRONT")
Mockingbird:registerAssetId("models/outfits.fbx/Prefab/AFemaleHat", "PREFAB_FORTUNE_FEMALE_HAT")
Mockingbird:registerAssetId("models/outfits.fbx/Prefab/AFemaleBelt", "PREFAB_FORTUNE_FEMALE_BELT")
Mockingbird:registerAssetId("models/outfits.fbx/Prefab/AMaleFront", "PREFAB_FORTUNE_MALE_FRONT")
Mockingbird:registerAssetId("models/outfits.fbx/Prefab/AMaleHat", "PREFAB_FORTUNE_MALE_HAT")
--new Path work
Mockingbird:registerAssetId("models/mockingbird.fbx/Prefab/Afortune_Part/PATH_C_1", "PATH_FORTUNE_WORK_C1")
Mockingbird:registerAssetId("models/mockingbird.fbx/Prefab/Afortune_Part/PATH_A_1", "PATH_FORTUNE_CUST_A1")
Mockingbird:registerAssetId("models/mockingbird.fbx/Prefab/Afortune_Part/PATH_B_1", "PATH_FORTUNE_CUST_B1")



Mockingbird:registerPrefabComponent("models/mockingbird.fbx/Prefab/Afortune_Part", {
    DataType = "COMP_BUILDING_PART",
    PathList = {
        {   
            PathType = "DEFAULT",
            WayPointList = {
                "PATH_FORTUNE_WORK_C1"
            }
        },
        {   
            PathType = "PICKUP",
            WayPointList = {
                "PATH_FORTUNE_CUST_A1"
            }
        },
        {   
            PathType = "PICKUP",
            WayPointList = {
                "PATH_FORTUNE_CUST_B1"
            }
        }
    }
})
--------------------
-- Scaling Building Parts --
--------------------

Mockingbird:register({
	DataType = "BUILDING_PART",
	Id = "ALAMP_PART",
	Name = "ALAMP_NAME",
	Description = "ALAMP_DESC",
    IsMovableWhenBuilt = true,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER",
		CoreObjectPrefab = "PREFAB_ROOT_PART",
		EndPart = "ALAMP",
		FillerList = {
			"TILING"
    	},
		BasementFillerList = {
			"TILING"
       	},
		MinimumScale = 2,
		IsVertical = true
	},
		DesirabilityModifiers = {
		{
			Desirability = "DESIRABILITY_RESIDENTIAL",
			Type = "ADD",
			Radius = 20.0,
			Value = 0.5
		}
	},
	AssetBuildingFunction = "MAGIC_GENERATOR_FUNCTION" --"BUILDING_FUNCTION_MAGIC_GENERATOR"
})
Mockingbird:register({
	DataType = "BUILDING_PART",
	Id = "ALAMP",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_ALAMP_PART"
	}
})

Mockingbird:register({
	DataType = "BUILDING_PART",
	Id = "ADIRT_PART",
	Name = "ADIRT_NAME",
	Description = "ADIRT_DESC",
    IsMovableWhenBuilt = true,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER",
		CoreObjectPrefab = "PREFAB_ROOT_PART",
		EndPart = "ADIRT",
		FillerList = {
			"TILING"
    	},
		BasementFillerList = {
			"TILING"
       	},
		MinimumScale = 2,
		IsVertical = true
	},
		BuildingZone = {
		ZoneEntryList = {
			{
				Type = {
					DEFAULT = true,
					NAVIGABLE = true,
					GRASS_CLEAR = true
				},
				Polygon = polygon.createRectangle( {0.08, 0.4}, {0, 0} )
			}
		}
	},
		DesirabilityModifiers = {
		{
			Desirability = "DESIRABILITY_RESIDENTIAL",
			Type = "ADD",
			Radius = 20.0,
			Value = 0.5
		}
	},
	AssetBuildingFunction = "MAGIC_GENERATOR_FUNCTION" --"BUILDING_FUNCTION_MAGIC_GENERATOR"
})
Mockingbird:register({
	DataType = "BUILDING_PART",
	Id = "ADIRT",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_ADIRT_PART"
	}
})

---------------
-- Building Part: Fortuneteller Table --
---------------
Mockingbird:register({
    DataType = "BUILDING_PART",
    Id = "AFORTUNE_PART",
    Name = "AFORTUNE_NAME",
    Description = "AFORTUNE_DESC",
    IsMovableWhenBuilt = true,
    ConstructorData = {
        DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
        CoreObjectPrefab = "PREFAB_AFORTUNE_PART"
    },
	BuildingZone = {
		ZoneEntryList = {
			{
				Type = {
					DEFAULT = true,
					NAVIGABLE = false
				},
				Polygon = polygon.createCircle( 0.4, {0, 0}, 8 )
			}
		}
	},
	AssetBuildingFunction = "BUILDING_FUNCTION_FORTUNETELLER",		
		DesirabilityModifiers = {
		{
			Desirability = "DESIRABILITY_RESIDENTIAL",
			Type = "ADD",
			Radius = 20.0,
			Value = 0.5
		}
	}
})
---------------
-- Building Function: Fortuneteller's Table --
---------------
Mockingbird:register({
    DataType = "BUILDING_FUNCTION_MARKET",
    Id = "BUILDING_FUNCTION_FORTUNETELLER",
    Name = "BUILDING_FUNCTION_FORTUNETELLER_NAME",
    IsPrivate = false,
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "JOB_FORTUNETELLER", 
        Behavior = "BEHAVIOR_WORK"
    },
    TypeList = { "RESOURCE_MAGIC" },
    IsOverrideCapacity = true,
    CapacityPerSlot = 50,
    InputInventoryCapacity = {
    },
    ResourceListNeeded = {
    },
    ResourceProduced = {
        { Resource = "RESOURCE_MAGIC", Quantity = 1 },
    }
})
---------------
-- Job: Fortuneteller --
---------------
Mockingbird:register({
	DataType = "JOB",
	Id = "JOB_FORTUNETELLER",
	JobName = "JOB_FORTUNETELLER_NAME",
	JobDescription = "JOB_FORTUNETELLER_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
	-- UseWorkplaceBehavior = true,
    ProductionDelay = 20.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP", 
--		LeftHandObject = {
--		Model = "PREFAB_TOOL_WINE_MAKER_STICK",
--		WorkAttachName = "Scroll_Anchor", 
--		WalkAttachName = "Scroll_Anchor"
--	},
      FemaleFrontList = {
             "PREFAB_FORTUNE_FEMALE_FRONT",
         },
      FemaleHatList = {
            "PREFAB_FORTUNE_FEMALE_HAT",
		},
       FemaleBeltList = {
            "PREFAB_FORTUNE_FEMALE_BELT",
        },     
        MaleFrontList = {
             "PREFAB_FORTUNE_MALE_FRONT",
        },
        MaleHatList = {
             "PREFAB_FORTUNE_MALE_HAT",
        },
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE"
	}
})

Mockingbird:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FORTUNETELLER"
    }
})

Mockingbird:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FORTUNETELLER"
    }
})

Mockingbird:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FORTUNETELLER"
    }
})

Mockingbird:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FORTUNETELLER"
    }
})